import 'package:build_cli_annotations/build_cli_annotations.dart';

import 'package:args/args.dart';

part 'options.g.dart';

Options parseArgs(List<String> args) {
  return parseOptions(args);
}

String generateUsage() => _$parserForOptions.usage;

@CliOptions()
class Options {
  @CliOption(
    name: 'install',
    abbr: 'i',
    help: 'Add a package to your pubspec.yaml',
    valueHelp: 'package_name[:[version]]',
  )
  final String install;

  final bool installWasParsed;

  @CliOption(
    name: 'delete',
    abbr: 'd',
    help: 'Delete a package from your pubspec.yaml',
    valueHelp: 'package_name',
  )
  final String delete;

  final bool deleteWasParsed;

  @CliOption(
    name: 'dev',
    defaultsTo: false,
    help:
        'Put the package addition to the dev_dependencies section of your pubspec',
  )
  final bool devDependencies;

  @CliOption(
    name: 'pub-host-url',
    defaultsTo: 'https://pub.dartlang.org',
    help: 'Define the url of the pub instance',
    valueHelp: 'pub_host_url',
  )
  final String pubHostUrl;

  @CliOption(
    name: 'get',
    defaultsTo: false,
    help: 'Run pub get after modifying dependencies',
  )
  final bool runPubGet;

  final bool runPubGetWasParsed;

  @CliOption(
    name: 'next-breaking',
    help:
        'Auto update version when there is a breaking change in your librairie',
  )
  final bool nextBreakingVersion;

  final bool nextBreakingVersionWasParsed;

  @CliOption(
    name: 'next-major',
    help: 'Bump the major number of the version',
  )
  final bool nextMajor;

  final bool nextMajorWasParsed;

  @CliOption(
    name: 'next-minor',
    help: 'Bump the minor number of the version',
  )
  final bool nextMinor;

  final bool nextMinorWasParsed;

  @CliOption(
    name: 'next-patch',
    help: 'Bump the patch number of the version',
  )
  final bool nextPatch;

  final bool nextPatchWasParsed;

  const Options({
    this.install,
    this.installWasParsed,
    this.delete,
    this.deleteWasParsed,
    this.devDependencies,
    this.pubHostUrl,
    this.runPubGet,
    this.runPubGetWasParsed,
    this.nextBreakingVersion,
    this.nextBreakingVersionWasParsed,
    this.nextMajor,
    this.nextMajorWasParsed,
    this.nextMinor,
    this.nextMinorWasParsed,
    this.nextPatch,
    this.nextPatchWasParsed,
  });
}
